comment="Microwave domestic oven with vertical feeding waveguide";
bitmap="ovenv0.bmp";

PAR( "Object name", onam, ovenv );
PAR( "Oven z-dim", oh, 188 );
PAR( "Oven x-dim", ol, 267 );
PAR( "Oven y-dim", ow, 270 );
PAR( "Feeding waveguide z-dim", fwh, 18 );
PAR( "Feeding waveguide x-dim", fwl, 80 );
PAR( "Feeding waveguide y-dim", fww, 78 );
PAR( "Feeding waveguide z-position (from side)", fwx, 0 );
PAR( "Feeding waveguide y-position (from centre)", fwy, 0 );
PAR( "Shelf diameter", sd, 227 );
PAR( "Shelf height (z-dir)", sh, 6 );
PAR( "Shelf z-position", sz, 15 );
PAR( "Shelf medium", smed, glass );
PAR("Pizza diameter", pd, 120 ); 
PAR("Lower layer height (z-dir)", llh, 25 );
PAR("Upper layer height (z-dir)", ulh, 10 );
PAR("Sectors", NN, 32);
PAR("Medium", lmed, bread);
PAR("Susceptor thickness position", sth, 0.9);

ENDHEADER;

TEST( oh>0, "Oven height should be greater than 0" );
TEST( ol>0, "Oven length should be greater than 0" );
TEST( ow>0, "Oven width should be greater than 0" );
TEST( fwh>0, "Feeding waveguide height should be greater than 0" );
TEST( fwl>0, "Feeding waveguide length should be greater than 0" );
TEST( fww>0, "Feeding waveguide width should be greater than 0" );
TEST( fwx<=ol-fwh&&fwx>=0, "Feeding waveguide should be inside the oven" );
TEST( fwy<=ow/2-fww/2&&fwy>=-ow/2+fww/2, "Feeding waveguide should be inside the oven" );
TEST( sd>0, "Shelf diameter should be greater than 0" );
TEST( sh>0, "Shelf height should be greater than 0" );
TEST( sz>0, "Shelf z-position should be greater than 0" );

TEST( NN > 2, "N must be greater than 2" ); 
TEST( pd > 0, "Pizza diamter must be positive" );
TEST( llh > 0, "Lower layer height must be positive" );
TEST( ulh > 0, "Upper layer height must be positive" );

OPENOBJECT(onam);

# Draw the oven
CALL( "elements/cubic.udo", onam@box, ol, ow, oh, air, x, y, z, 9 );

# Draw the feeding waveguide
CALL( "elements/cubic.udo", onam@fw, fwl, fww, fwh, air, x+ol/2+fwl/2, y+fwy, z+oh-fwh-fwx, 9 );

# Draw the shelf
#CALL( "elements/cyv.udo", onam@shelf, sd/2, sh, 32, smed,"E", x, y, z+sz, 10 );
CALL( "elements/cyv.udo", onam@shelf, sd/2, sh, 32, smed,"N", x, y, z+sz, 10 );

# Draw port
CALL( "elements/portx.udo", onam@port, fwh, fww, "DOWN", 1, fwl/2, "ovenvport", x+ol/2+fwl, y-fww/2, z+oh-fwh, 11 );

#Draw bread
CALL( "elements/cyv.udo", oname@bread, pd/2, llh, NN, lmed,"E", x, y, z+sz+sh+sth, 10 );

Rs=105;
sigma=1000/(sth*Rs);
MEDIUMPAR(susceptor, 1,1,sigma, 0, 1,1,sigma, 0,1,1,0, 0,0);
#Draw susceptor
CALL( "basic/cyvo.udo", susceptor, pd/2, sth, NN, susceptor,"N", x, y, z+sz+sh, 10);

CLOSEOBJ;
